@@ -39,8 +39,13 @@ class SentenceTransformer(nn.Sequential):
             model_path = model_name_or_path
 
             if not os.path.isdir(model_path) and not model_path.startswith('http://') and not model_path.startswith('https://'):
-                logging.info("Did not find folder {}. Assume to download model from server.".format(model_path))
+                logging.info("Did not find folder {}".format(model_path))
+
+                if '\\' in model_path or model_path.count('/') > 1:
+                    raise AttributeError("Path {} not found".format(model_path))
+
                 model_path = __DOWNLOAD_SERVER__ + model_path + '.zip'
+                logging.info("Try to download model from server: {}".format(model_path))
 
             if model_path.startswith('http://') or model_path.startswith('https://'):
                 model_url = model_path
@@ -55,20 +60,22 @@ class SentenceTransformer(nn.Sequential):
                             os.getenv('XDG_CACHE_HOME', '~/.cache'), 'torch')))
                 default_cache_path = os.path.join(torch_cache_home, 'sentence_transformers')
                 model_path = os.path.join(default_cache_path, folder_name)
-                os.makedirs(model_path, exist_ok=True)
 
-                if not os.listdir(model_path):
+                if not os.path.exists(model_path) or not os.listdir(model_path):
                     if model_url[-1] == "/":
                         model_url = model_url[:-1]
                     logging.info("Downloading sentence transformer model from {} and saving it at {}".format(model_url, model_path))
+
+                    model_path_tmp = model_path.rstrip("/").rstrip("\\")+"_part"
                     try:
-                        zip_save_path = os.path.join(model_path, 'model.zip')
+                        zip_save_path = os.path.join(model_path_tmp, 'model.zip')
                         http_get(model_url, zip_save_path)
                         with ZipFile(zip_save_path, 'r') as zip:
-                            zip.extractall(model_path)
+                            zip.extractall(model_path_tmp)
                         os.remove(zip_save_path)
+                        os.rename(model_path_tmp, model_path)
                     except requests.exceptions.HTTPError as e:
-                        shutil.rmtree(model_path)
+                        shutil.rmtree(model_path_tmp)
                         if e.response.status_code == 404:
                             logging.warning('SentenceTransformer-Model {} not found. Try to create it from scratch'.format(model_url))
                             logging.warning('Try to create Transformer Model {} with mean pooling'.format(model_name_or_path))
@@ -179,15 +186,15 @@ class SentenceTransformer(nn.Sequential):
                     input_mask_expanded = input_mask.unsqueeze(-1).expand(embeddings.size()).float()
                     embeddings = embeddings * input_mask_expanded
 
-                all_embeddings.extend(embeddings)
-
+                for emb in embeddings:
+                    all_embeddings.append(emb.detach())
 
         all_embeddings = [all_embeddings[idx] for idx in np.argsort(length_sorted_idx)]
 
         if convert_to_tensor:
             all_embeddings = torch.stack(all_embeddings)
         elif convert_to_numpy:
-            all_embeddings = np.asarray([emb.cpu().detach().numpy() for emb in all_embeddings])
+            all_embeddings = np.asarray([emb.cpu().numpy() for emb in all_embeddings])
 
         if input_was_string:
             all_embeddings = all_embeddings[0]
@@ -315,7 +322,11 @@ class SentenceTransformer(nn.Sequential):
         return self._first_module().get_sentence_features(*features)
 
     def get_sentence_embedding_dimension(self):
-        return self._last_module().get_sentence_embedding_dimension()
+        for mod in reversed(self._modules.values()):
+            sent_embedding_dim_method = getattr(mod, "get_sentence_embedding_dimension", None)
+            if callable(sent_embedding_dim_method):
+                return sent_embedding_dim_method()
+        return None
 
     def _first_module(self):
         """Returns the first module of this sequential embedder"""
@@ -332,6 +343,8 @@ class SentenceTransformer(nn.Sequential):
         if path is None:
             return
 
+        os.makedirs(path, exist_ok=True)
+
         logging.info("Save model to {}".format(path))
         contained_modules = []
 
@@ -432,7 +445,7 @@ class SentenceTransformer(nn.Sequential):
 
     def fit(self,
             train_objectives: Iterable[Tuple[DataLoader, nn.Module]],
-            evaluator: SentenceEvaluator,
+            evaluator: SentenceEvaluator = None,
             epochs: int = 1,
             steps_per_epoch = None,
             scheduler: str = 'WarmupLinear',
@@ -442,11 +455,11 @@ class SentenceTransformer(nn.Sequential):
             weight_decay: float = 0.01,
             evaluation_steps: int = 0,
             output_path: str = None,
-            output_path_ignore_not_empty: bool = False,
             save_best_model: bool = True,
             max_grad_norm: float = 1,
             use_amp: bool = False,
             callback: Callable[[float, int, int], None] = None,
+            output_path_ignore_not_empty: bool = False
             ):
         """
         Train the model with the given training objective
@@ -465,13 +478,13 @@ class SentenceTransformer(nn.Sequential):
         :param weight_decay: Weight decay for model parameters
         :param evaluation_steps: If > 0, evaluate the model using evaluator after each number of training steps
         :param output_path: Storage path for the model and evaluation files
-        :param output_path_ignore_not_empty: By default, training will stop if output_path is not empty. If set to true, this error will be ignored and training proceeds.
         :param save_best_model: If true, the best model (according to evaluator) is stored at output_path
         :param max_grad_norm: Used for gradient normalization.
         :param use_amp: Use Automatic Mixed Precision (AMP). Only for Pytorch >= 1.6.0
         :param callback: Callback function that is invoked after each evaluation.
                 It must accept the following three parameters in this order:
                 `score`, `epoch`, `steps`
+        :param output_path_ignore_not_empty: deprecated, no longer used
         """
 
         if use_amp:
@@ -482,9 +495,6 @@ class SentenceTransformer(nn.Sequential):
 
         if output_path is not None:
             os.makedirs(output_path, exist_ok=True)
-            if not output_path_ignore_not_empty and len(os.listdir(output_path)) > 0:
-                raise ValueError("Output directory ({}) already exists and is not empty.".format(
-                    output_path))
 
         dataloaders = [dataloader for dataloader, _ in train_objectives]
 
@@ -493,10 +503,8 @@ class SentenceTransformer(nn.Sequential):
             dataloader.collate_fn = self.smart_batching_collate
 
         loss_models = [loss for _, loss in train_objectives]
-        device = self._target_device
-
         for loss_model in loss_models:
-            loss_model.to(device)
+            loss_model.to(self._target_device)
 
         self.best_score = -9999999
 
@@ -574,8 +582,8 @@ class SentenceTransformer(nn.Sequential):
 
                     optimizer.zero_grad()
 
-                if not skip_scheduler:
-                    scheduler.step()
+                    if not skip_scheduler:
+                        scheduler.step()
 
                 training_steps += 1
                 global_step += 1
@@ -587,8 +595,7 @@ class SentenceTransformer(nn.Sequential):
                         loss_model.zero_grad()
                         loss_model.train()
 
-            self._eval_during_training(evaluator, output_path, save_best_model, epoch,
-                                       -1, callback)
+            self._eval_during_training(evaluator, output_path, save_best_model, epoch, -1, callback)
 
     def evaluate(self, evaluator: SentenceEvaluator, output_path: str = None):
         """
@@ -615,7 +622,8 @@ class SentenceTransformer(nn.Sequential):
                     self.save(output_path)
 
 
-    def _get_scheduler(self, optimizer, scheduler: str, warmup_steps: int, t_total: int):
+    @staticmethod
+    def _get_scheduler(optimizer, scheduler: str, warmup_steps: int, t_total: int):
         """
         Returns the correct learning rate scheduler. Available scheduler: constantlr, warmupconstant, warmuplinear, warmupcosine, warmupcosinewithhardrestarts
         """
